@@ -3,7 +3,7 @@ package Fey::Literal::Null;
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use Fey::Types;
 
@@ -11,9 +11,9 @@ use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
-extends 'Fey::Literal';
-
-with 'Fey::Role::Comparable', 'Fey::Role::Selectable';
+with 'Fey::Role::Comparable',
+     'Fey::Role::Selectable',
+     'Fey::Role::IsLiteral';
 
 
 sub sql { 'NULL' }
@@ -54,6 +54,10 @@ This class provides the following methods:
 
 This method creates a new C<Fey::Literal::Null> object.
 
+=head2 $null->id()
+
+The id for a null is always just "NULL".
+
 =head2 $null->sql()
 
 =head2 $null->sql_with_alias()
