@@ -3,7 +3,7 @@ package Fey::Literal::Number;
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use Fey::Types;
 
@@ -11,9 +11,9 @@ use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
-extends 'Fey::Literal';
-
-with 'Fey::Role::Comparable', 'Fey::Role::Selectable';
+with 'Fey::Role::Comparable',
+     'Fey::Role::Selectable',
+     'Fey::Role::IsLiteral';
 
 has 'number' =>
     ( is       => 'ro',
@@ -73,6 +73,10 @@ the number passed to the constructor.
 
 Returns the number as passed to the constructor.
 
+=head2 $number->id()
+
+The id for a number is always just the number itself.
+
 =head2 $number->sql()
 
 =head2 $number->sql_with_alias()
