@@ -3,7 +3,7 @@ package Fey::Literal::String;
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use Fey::Types;
 
@@ -11,9 +11,9 @@ use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 
-extends 'Fey::Literal';
-
-with 'Fey::Role::Comparable', 'Fey::Role::Selectable';
+with 'Fey::Role::Comparable',
+     'Fey::Role::Selectable',
+     'Fey::Role::IsLiteral';
 
 has 'string' =>
     ( is       => 'ro',
@@ -72,6 +72,10 @@ the string passed to the constructor.
 
 Returns the string as passed to the constructor.
 
+=head2 $string->id()
+
+The id for a string is always just the string itself.
+
 =head2 $string->sql()
 
 =head2 $string->sql_with_alias()
